define(
//begin v1.x content
({
	"findLabel": "Søk:",
	"findTooltip": "Skriv inn teksten du vil søke etter",
	"replaceLabel": "Erstatt med:",
	"replaceTooltip": "Skriv inn teksten du vil erstatte med",
	"findReplace": "Søk og erstatt",
	"matchCase": "Skill mellom store og små bokstaver",
	"matchCaseTooltip": "Skill mellom store og små bokstaver",
	"backwards": "Bakover",
	"backwardsTooltip": "Søk bakover etter tekst",
	"replaceAllButton": "Erstatt alle",
	"replaceAllButtonTooltip": "Erstatt all tekst",
	"findButton": "Søk",
	"findButtonTooltip": "Søk etter teksten",
	"replaceButton": "Erstatt",
	"replaceButtonTooltip": "Erstatt teksten",
	"replaceDialogText": "Erstattet ${0} forekomster.",
	"eofDialogText": "Siste forekomst ${0}",
	"eofDialogTextFind": "funnet",
	"eofDialogTextReplace": "erstattet"
})
//end v1.x content
);
